@@ -12,28 +12,28 @@
 #' Some methods requires additional parameters. These parameters are mentioned
 #' in the indented blocks for each method and their definitions are provided at
 #' the end of this parameters list.
-#'   - `slearner`: S-Learner.
-#'     - `oreg_method`
-#'   - `tlearner`: T-Learner.
-#'     - `oreg_method`
-#'   - `tpoisson`: T-Poisson.
+#'   -  \code{"slearner"}: S-Learner.
+#'     - `learner_y`
+#'   - \code{"tlearner"}: T-Learner.
+#'     - `learner_y`
+#'   - \code{"tpoisson"}: T-Poisson.
 #'     - `offset`
-#'   - `xlearner`: X-Learner.
-#'     - `oreg_method`
-#'   - `aipw`: Augmented Inverse Probability Weighting.
-#'     - `ps_method` and  `oreg_method`
-#'   - `bart`: Bayesian Additive Regression Trees.
-#'     - `ps_method`
-#'   - `cf`: Causal Forest.
-#'     - `ps_method`
+#'   - \code{"xlearner"}: X-Learner.
+#'     - `learner_y`
+#'   - \code{"aipw"}: Augmented Inverse Probability Weighting.
+#'     - `learner_ps` and  `learner_y`
+#'   - \code{"bart"}: Bayesian Additive Regression Trees.
+#'     - `learner_ps`
+#'   - \code{"cf"}: Causal Forest.
+#'     - `learner_ps`
 #' @param ... Additional parameters passed to different models.
 #' @details
 #' ## Additional parameters
-#'   - **ps_method**: An estimation method for the propensity score. This
+#'   - **learner_ps**: An estimation method for the propensity score. This
 #'   includes libraries for the SuperLearner package.
-#'   - **oreg_method**: An estimation model for the outcome regressions. This
-#'   includes libraries for the SuperLearner package.
-#'   - **offset**: Name of the covariate to use as offset (i.e. 'x1') for
+#'   - **learner_y**: An estimation model for the outcome. This includes
+#'   libraries for the SuperLearner package.
+#'   - **offset**: Name of the covariate to use as offset (i.e. \code{"x1"}) for
 #'     Poisson ITE Estimation. `NULL` if offset is not used.
 #'
 #' @return
@@ -46,9 +46,7 @@ estimate_ite <- function(y, z, X, ite_method, ...) {
   logger::log_debug("Estimating ITE...")
   st_time <- proc.time()
   # Address visible binding error.
-  offset <- oreg_method <- NULL
-  ps_method <- ps_method_dis <- ps_method_inf <- NULL
-
+  offset <- learner_y <- learner_ps <- NULL
 
 
   ## collect additional arguments
@@ -69,23 +67,23 @@ estimate_ite <- function(y, z, X, ite_method, ...) {
   }
 
   if (ite_method == "slearner") {
-    check_args(c("oreg_method"), arg_names)
-    ite <- estimate_ite_slearner(y, z, X, oreg_method)
+    check_args(c("learner_y"), arg_names)
+    ite <- estimate_ite_slearner(y, z, X, learner_y)
   } else if (ite_method == "tlearner") {
-    check_args(c("oreg_method"), arg_names)
-    ite <- estimate_ite_tlearner(y, z, X, oreg_method)
+    check_args(c("learner_y"), arg_names)
+    ite <- estimate_ite_tlearner(y, z, X, learner_y)
   } else if (ite_method == "xlearner") {
-    check_args(c("oreg_method"), arg_names)
-    ite <- estimate_ite_xlearner(y, z, X, oreg_method)
+    check_args(c("learner_y"), arg_names)
+    ite <- estimate_ite_xlearner(y, z, X, learner_y)
   }else if (ite_method == "aipw") {
-    check_args(c("ps_method", "oreg_method"), arg_names)
-    ite <- estimate_ite_aipw(y, z, X, ps_method, oreg_method)
+    check_args(c("learner_ps", "learner_y"), arg_names)
+    ite <- estimate_ite_aipw(y, z, X, learner_ps, learner_y)
   } else if (ite_method == "bart") {
-    check_args(c("ps_method"), arg_names)
-    ite <- estimate_ite_bart(y, z, X, ps_method)
+    check_args(c("learner_ps"), arg_names)
+    ite <- estimate_ite_bart(y, z, X, learner_ps)
   } else if (ite_method == "cf") {
-    check_args(c("ps_method"), arg_names)
-    ite <- estimate_ite_cf(y, z, X, ps_method)
+    check_args(c("learner_ps"), arg_names)
+    ite <- estimate_ite_cf(y, z, X, learner_ps)
   } else if (ite_method == "tpoisson") {
     check_args(c("offset"), arg_names)
     ite <- estimate_ite_tpoisson(y, z, X, offset)
