@@ -1,29 +1,29 @@
 #' @title
-#' Estimate the Individual Treatment Effect (ITE) using S-Learner.
+#' Estimate the Individual Treatment Effect (ITE) using S-Learner
 #'
 #' @description
 #' Estimates the Individual Treatment Effect using S-Learner given a response
 #' vector, a treatment vector, a features matrix and estimation model for the
-#' outcome regressions.
+#' outcome.
 #'
 #' @param y An observed response vector.
 #' @param z A treatment vector.
 #' @param X A features matrix.
-#' @param oreg_method An estimation model for the outcome regressions.
+#' @param learner_y An estimation model for the outcome.
 #'
 #' @return
 #' A list of ITE estimates.
 #'
 #' @keywords internal
 #'
-estimate_ite_slearner <- function(y, z, X, oreg_method = "SL.xgboost") {
+estimate_ite_slearner <- function(y, z, X, learner_y = "SL.xgboost") {
 
-  logger::log_trace("oreg_method: '{oreg_method}' was selected.")
+  logger::log_trace("learner_y: '{learner_y}' was selected.")
 
   y_model <- SuperLearner::SuperLearner(Y = y,
                                         X = data.frame(X = X, Z = z),
                                         family = gaussian(),
-                                        SL.library = oreg_method,
+                                        SL.library = learner_y,
                                         cvControl = list(V = 0))
 
   if (sum(y_model$coef) == 0) y_model$coef[1] <- 1
