@@ -34,7 +34,7 @@ generate_rules <- function(X, ite, ntrees, node_size, max_rules, max_depth) {
                                          nodesize = node_size,
                                          mtry = ncol(X)*2/3)
 
-    treelist <- inTrees::RF2List(forest)
+    treelist <- inTrees_RF2List(forest)
     rules <- extract_rules(treelist, X, max_depth)
   } else {
     rules <- NULL
